# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/grpc_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/core/grpc_service.proto',
  package='envoy.api.v2.core',
  syntax='proto3',
  serialized_options=b'\n\037io.envoyproxy.envoy.api.v2.coreB\020GrpcServiceProtoP\001\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/api/v2/core/grpc_service.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8f\x12\n\x0bGrpcService\x12>\n\nenvoy_grpc\x18\x01 \x01(\x0b\x32(.envoy.api.v2.core.GrpcService.EnvoyGrpcH\x00\x12@\n\x0bgoogle_grpc\x18\x02 \x01(\x0b\x32).envoy.api.v2.core.GrpcService.GoogleGrpcH\x00\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x10initial_metadata\x18\x05 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x1a*\n\tEnvoyGrpc\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a\xcc\x0f\n\nGoogleGrpc\x12\x1b\n\ntarget_uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12Y\n\x13\x63hannel_credentials\x18\x02 \x01(\x0b\x32<.envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials\x12S\n\x10\x63\x61ll_credentials\x18\x03 \x03(\x0b\x32\x39.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials\x12\x1c\n\x0bstat_prefix\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12 \n\x18\x63redentials_factory_name\x18\x05 \x01(\t\x12\'\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\xb2\x01\n\x0eSslCredentials\x12\x31\n\nroot_certs\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12:\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x31\n\ncert_chain\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x1a\x18\n\x16GoogleLocalCredentials\x1a\x97\x02\n\x12\x43hannelCredentials\x12S\n\x0fssl_credentials\x18\x01 \x01(\x0b\x32\x38.envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentialsH\x00\x12\x30\n\x0egoogle_default\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12]\n\x11local_credentials\x18\x03 \x01(\x0b\x32@.envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentialsH\x00\x42\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x1a\x9e\t\n\x0f\x43\x61llCredentials\x12\x16\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tH\x00\x12\x37\n\x15google_compute_engine\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x1e\n\x14google_refresh_token\x18\x03 \x01(\tH\x00\x12\x82\x01\n\x1aservice_account_jwt_access\x18\x04 \x01(\x0b\x32\\.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentialsH\x00\x12\x64\n\ngoogle_iam\x18\x05 \x01(\x0b\x32N.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentialsH\x00\x12n\n\x0b\x66rom_plugin\x18\x06 \x01(\x0b\x32W.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPluginH\x00\x12[\n\x0bsts_service\x18\x07 \x01(\x0b\x32\x44.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsServiceH\x00\x1aV\n\"ServiceAccountJWTAccessCredentials\x12\x10\n\x08json_key\x18\x01 \x01(\t\x12\x1e\n\x16token_lifetime_seconds\x18\x02 \x01(\x04\x1aO\n\x14GoogleIAMCredentials\x12\x1b\n\x13\x61uthorization_token\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthority_selector\x18\x02 \x01(\t\x1a\x99\x01\n\x1dMetadataCredentialsFromPlugin\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\x1a\xff\x01\n\nStsService\x12\"\n\x1atoken_exchange_service_uri\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1c\n\x14requested_token_type\x18\x05 \x01(\t\x12#\n\x12subject_token_path\x18\x06 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12#\n\x12subject_token_type\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x18\n\x10\x61\x63tor_token_path\x18\x08 \x01(\t\x12\x18\n\x10\x61\x63tor_token_type\x18\t \x01(\tB\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x42\x17\n\x10target_specifier\x12\x03\xf8\x42\x01J\x04\x08\x04\x10\x05\x42Y\n\x1fio.envoyproxy.envoy.api.v2.coreB\x10GrpcServiceProtoP\x01\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_GRPCSERVICE_ENVOYGRPC = _descriptor.Descriptor(
  name='EnvoyGrpc',
  full_name='envoy.api.v2.core.GrpcService.EnvoyGrpc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.api.v2.core.GrpcService.EnvoyGrpc.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=577,
  serialized_end=619,
)

_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS = _descriptor.Descriptor(
  name='SslCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_certs', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials.root_certs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials.private_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cert_chain', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials.cert_chain', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=947,
  serialized_end=1125,
)

_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS = _descriptor.Descriptor(
  name='GoogleLocalCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1151,
)

_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS = _descriptor.Descriptor(
  name='ChannelCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ssl_credentials', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials.ssl_credentials', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_default', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials.google_default', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_credentials', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials.local_credentials', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='credential_specifier', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials.credential_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1154,
  serialized_end=1433,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS = _descriptor.Descriptor(
  name='ServiceAccountJWTAccessCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_key', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials.json_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_lifetime_seconds', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials.token_lifetime_seconds', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2008,
  serialized_end=2094,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS = _descriptor.Descriptor(
  name='GoogleIAMCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='authorization_token', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials.authorization_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority_selector', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials.authority_selector', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2096,
  serialized_end=2175,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN = _descriptor.Descriptor(
  name='MetadataCredentialsFromPlugin',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin.typed_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2178,
  serialized_end=2331,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE = _descriptor.Descriptor(
  name='StsService',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token_exchange_service_uri', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.token_exchange_service_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.resource', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audience', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.audience', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.scope', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_token_type', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.requested_token_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_token_path', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.subject_token_path', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_token_type', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.subject_token_type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_token_path', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.actor_token_path', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_token_type', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService.actor_token_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2334,
  serialized_end=2589,
)

_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS = _descriptor.Descriptor(
  name='CallCredentials',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_compute_engine', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.google_compute_engine', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_refresh_token', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.google_refresh_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_jwt_access', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.service_account_jwt_access', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_iam', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.google_iam', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_plugin', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.from_plugin', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sts_service', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.sts_service', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN, _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='credential_specifier', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.credential_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1436,
  serialized_end=2618,
)

_GRPCSERVICE_GOOGLEGRPC = _descriptor.Descriptor(
  name='GoogleGrpc',
  full_name='envoy.api.v2.core.GrpcService.GoogleGrpc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_uri', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.target_uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_credentials', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.channel_credentials', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='call_credentials', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.call_credentials', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.stat_prefix', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='credentials_factory_name', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.credentials_factory_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.api.v2.core.GrpcService.GoogleGrpc.config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS, _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=2618,
)

_GRPCSERVICE = _descriptor.Descriptor(
  name='GrpcService',
  full_name='envoy.api.v2.core.GrpcService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='envoy_grpc', full_name='envoy.api.v2.core.GrpcService.envoy_grpc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='google_grpc', full_name='envoy.api.v2.core.GrpcService.google_grpc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.api.v2.core.GrpcService.timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_metadata', full_name='envoy.api.v2.core.GrpcService.initial_metadata', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRPCSERVICE_ENVOYGRPC, _GRPCSERVICE_GOOGLEGRPC, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target_specifier', full_name='envoy.api.v2.core.GrpcService.target_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=330,
  serialized_end=2649,
)

_GRPCSERVICE_ENVOYGRPC.containing_type = _GRPCSERVICE
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['root_certs'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['cert_chain'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['ssl_credentials'].message_type = _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['google_default'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['local_credentials'].message_type = _GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['ssl_credentials'])
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['ssl_credentials'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['google_default'])
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['google_default'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['local_credentials'])
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.fields_by_name['local_credentials'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.containing_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.oneofs_by_name['config_type'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.oneofs_by_name['config_type']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.oneofs_by_name['config_type'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['typed_config'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['typed_config'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.oneofs_by_name['config_type']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.containing_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_compute_engine'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['service_account_jwt_access'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_iam'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['from_plugin'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['sts_service'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.containing_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['access_token'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['access_token'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_compute_engine'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_compute_engine'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_refresh_token'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_refresh_token'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['service_account_jwt_access'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['service_account_jwt_access'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_iam'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['google_iam'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['from_plugin'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['from_plugin'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier'].fields.append(
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['sts_service'])
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.fields_by_name['sts_service'].containing_oneof = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['channel_credentials'].message_type = _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['call_credentials'].message_type = _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_GRPCSERVICE_GOOGLEGRPC.containing_type = _GRPCSERVICE
_GRPCSERVICE.fields_by_name['envoy_grpc'].message_type = _GRPCSERVICE_ENVOYGRPC
_GRPCSERVICE.fields_by_name['google_grpc'].message_type = _GRPCSERVICE_GOOGLEGRPC
_GRPCSERVICE.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GRPCSERVICE.fields_by_name['initial_metadata'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUE
_GRPCSERVICE.oneofs_by_name['target_specifier'].fields.append(
  _GRPCSERVICE.fields_by_name['envoy_grpc'])
_GRPCSERVICE.fields_by_name['envoy_grpc'].containing_oneof = _GRPCSERVICE.oneofs_by_name['target_specifier']
_GRPCSERVICE.oneofs_by_name['target_specifier'].fields.append(
  _GRPCSERVICE.fields_by_name['google_grpc'])
_GRPCSERVICE.fields_by_name['google_grpc'].containing_oneof = _GRPCSERVICE.oneofs_by_name['target_specifier']
DESCRIPTOR.message_types_by_name['GrpcService'] = _GRPCSERVICE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GrpcService = _reflection.GeneratedProtocolMessageType('GrpcService', (_message.Message,), {

  'EnvoyGrpc' : _reflection.GeneratedProtocolMessageType('EnvoyGrpc', (_message.Message,), {
    'DESCRIPTOR' : _GRPCSERVICE_ENVOYGRPC,
    '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.EnvoyGrpc)
    })
  ,

  'GoogleGrpc' : _reflection.GeneratedProtocolMessageType('GoogleGrpc', (_message.Message,), {

    'SslCredentials' : _reflection.GeneratedProtocolMessageType('SslCredentials', (_message.Message,), {
      'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS,
      '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentials)
      })
    ,

    'GoogleLocalCredentials' : _reflection.GeneratedProtocolMessageType('GoogleLocalCredentials', (_message.Message,), {
      'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS,
      '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentials)
      })
    ,

    'ChannelCredentials' : _reflection.GeneratedProtocolMessageType('ChannelCredentials', (_message.Message,), {
      'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS,
      '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials)
      })
    ,

    'CallCredentials' : _reflection.GeneratedProtocolMessageType('CallCredentials', (_message.Message,), {

      'ServiceAccountJWTAccessCredentials' : _reflection.GeneratedProtocolMessageType('ServiceAccountJWTAccessCredentials', (_message.Message,), {
        'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS,
        '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
        # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials)
        })
      ,

      'GoogleIAMCredentials' : _reflection.GeneratedProtocolMessageType('GoogleIAMCredentials', (_message.Message,), {
        'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS,
        '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
        # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials)
        })
      ,

      'MetadataCredentialsFromPlugin' : _reflection.GeneratedProtocolMessageType('MetadataCredentialsFromPlugin', (_message.Message,), {
        'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN,
        '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
        # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin)
        })
      ,

      'StsService' : _reflection.GeneratedProtocolMessageType('StsService', (_message.Message,), {
        'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE,
        '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
        # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsService)
        })
      ,
      'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS,
      '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
      # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials)
      })
    ,
    'DESCRIPTOR' : _GRPCSERVICE_GOOGLEGRPC,
    '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService.GoogleGrpc)
    })
  ,
  'DESCRIPTOR' : _GRPCSERVICE,
  '__module__' : 'envoy.api.v2.core.grpc_service_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.core.GrpcService)
  })
_sym_db.RegisterMessage(GrpcService)
_sym_db.RegisterMessage(GrpcService.EnvoyGrpc)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.SslCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.GoogleLocalCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.ChannelCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentials)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPlugin)
_sym_db.RegisterMessage(GrpcService.GoogleGrpc.CallCredentials.StsService)


DESCRIPTOR._options = None
_GRPCSERVICE_ENVOYGRPC.fields_by_name['cluster_name']._options = None
_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key']._options = None
_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config']._options = None
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_path']._options = None
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_type']._options = None
_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['target_uri']._options = None
_GRPCSERVICE_GOOGLEGRPC.fields_by_name['stat_prefix']._options = None
_GRPCSERVICE.oneofs_by_name['target_specifier']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/network/local_rate_limit/v2alpha/local_rate_limit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type import token_bucket_pb2 as envoy_dot_type_dot_token__bucket__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/network/local_rate_limit/v2alpha/local_rate_limit.proto',
  package='envoy.config.filter.network.local_rate_limit.v2alpha',
  syntax='proto3',
  serialized_options=b'\nBio.envoyproxy.envoy.config.filter.network.local_rate_limit.v2alphaB\023LocalRateLimitProtoP\001\362\230\376\217\0055\0223envoy.extensions.filters.network.local_ratelimit.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKenvoy/config/filter/network/local_rate_limit/v2alpha/local_rate_limit.proto\x12\x34\x65nvoy.config.filter.network.local_rate_limit.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1d\x65nvoy/type/token_bucket.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa7\x01\n\x0eLocalRateLimit\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x37\n\x0ctoken_bucket\x18\x02 \x01(\x0b\x32\x17.envoy.type.TokenBucketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12>\n\x0fruntime_enabled\x18\x03 \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlagB\x9e\x01\nBio.envoyproxy.envoy.config.filter.network.local_rate_limit.v2alphaB\x13LocalRateLimitProtoP\x01\xf2\x98\xfe\x8f\x05\x35\x12\x33\x65nvoy.extensions.filters.network.local_ratelimit.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_token__bucket__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_LOCALRATELIMIT = _descriptor.Descriptor(
  name='LocalRateLimit',
  full_name='envoy.config.filter.network.local_rate_limit.v2alpha.LocalRateLimit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.config.filter.network.local_rate_limit.v2alpha.LocalRateLimit.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token_bucket', full_name='envoy.config.filter.network.local_rate_limit.v2alpha.LocalRateLimit.token_bucket', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_enabled', full_name='envoy.config.filter.network.local_rate_limit.v2alpha.LocalRateLimit.runtime_enabled', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=450,
)

_LOCALRATELIMIT.fields_by_name['token_bucket'].message_type = envoy_dot_type_dot_token__bucket__pb2._TOKENBUCKET
_LOCALRATELIMIT.fields_by_name['runtime_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFEATUREFLAG
DESCRIPTOR.message_types_by_name['LocalRateLimit'] = _LOCALRATELIMIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocalRateLimit = _reflection.GeneratedProtocolMessageType('LocalRateLimit', (_message.Message,), {
  'DESCRIPTOR' : _LOCALRATELIMIT,
  '__module__' : 'envoy.config.filter.network.local_rate_limit.v2alpha.local_rate_limit_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.network.local_rate_limit.v2alpha.LocalRateLimit)
  })
_sym_db.RegisterMessage(LocalRateLimit)


DESCRIPTOR._options = None
_LOCALRATELIMIT.fields_by_name['stat_prefix']._options = None
_LOCALRATELIMIT.fields_by_name['token_bucket']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/rocketmq_proxy/v4alpha/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from envoy.type.matcher.v4alpha import string_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/rocketmq_proxy/v4alpha/route.proto',
  package='envoy.extensions.filters.network.rocketmq_proxy.v4alpha',
  syntax='proto3',
  serialized_options=b'\nEio.envoyproxy.envoy.extensions.filters.network.rocketmq_proxy.v4alphaB\nRouteProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nCenvoy/extensions/filters/network/rocketmq_proxy/v4alpha/route.proto\x12\x37\x65nvoy.extensions.filters.network.rocketmq_proxy.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\'envoy/type/matcher/v4alpha/string.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc0\x01\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12N\n\x06routes\x18\x02 \x03(\x0b\x32>.envoy.extensions.filters.network.rocketmq_proxy.v4alpha.Route:L\x9a\xc5\x88\x1eG\nEenvoy.extensions.filters.network.rocketmq_proxy.v3.RouteConfiguration\"\x85\x02\n\x05Route\x12\\\n\x05match\x18\x01 \x01(\x0b\x32\x43.envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12]\n\x05route\x18\x02 \x01(\x0b\x32\x44.envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:?\x9a\xc5\x88\x1e:\n8envoy.extensions.filters.network.rocketmq_proxy.v3.Route\"\xd2\x01\n\nRouteMatch\x12\x42\n\x05topic\x18\x01 \x01(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12:\n\x07headers\x18\x02 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher:D\x9a\xc5\x88\x1e?\n=envoy.extensions.filters.network.rocketmq_proxy.v3.RouteMatch\"\xab\x01\n\x0bRouteAction\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12;\n\x0emetadata_match\x18\x02 \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata:E\x9a\xc5\x88\x1e@\n>envoy.extensions.filters.network.rocketmq_proxy.v3.RouteActionB]\nEio.envoyproxy.envoy.extensions.filters.network.rocketmq_proxy.v4alphaB\nRouteProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROUTECONFIGURATION = _descriptor.Descriptor(
  name='RouteConfiguration',
  full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteConfiguration.routes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036G\nEenvoy.extensions.filters.network.rocketmq_proxy.v3.RouteConfiguration',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=542,
)


_ROUTE = _descriptor.Descriptor(
  name='Route',
  full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.Route',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.Route.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.Route.route', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.extensions.filters.network.rocketmq_proxy.v3.Route',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=545,
  serialized_end=806,
)


_ROUTEMATCH = _descriptor.Descriptor(
  name='RouteMatch',
  full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteMatch.topic', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteMatch.headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.extensions.filters.network.rocketmq_proxy.v3.RouteMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=1019,
)


_ROUTEACTION = _descriptor.Descriptor(
  name='RouteAction',
  full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteAction.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteAction.metadata_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036@\n>envoy.extensions.filters.network.rocketmq_proxy.v3.RouteAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1022,
  serialized_end=1193,
)

_ROUTECONFIGURATION.fields_by_name['routes'].message_type = _ROUTE
_ROUTE.fields_by_name['match'].message_type = _ROUTEMATCH
_ROUTE.fields_by_name['route'].message_type = _ROUTEACTION
_ROUTEMATCH.fields_by_name['topic'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._STRINGMATCHER
_ROUTEMATCH.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_ROUTEACTION.fields_by_name['metadata_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
DESCRIPTOR.message_types_by_name['RouteConfiguration'] = _ROUTECONFIGURATION
DESCRIPTOR.message_types_by_name['Route'] = _ROUTE
DESCRIPTOR.message_types_by_name['RouteMatch'] = _ROUTEMATCH
DESCRIPTOR.message_types_by_name['RouteAction'] = _ROUTEACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RouteConfiguration = _reflection.GeneratedProtocolMessageType('RouteConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ROUTECONFIGURATION,
  '__module__' : 'envoy.extensions.filters.network.rocketmq_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteConfiguration)
  })
_sym_db.RegisterMessage(RouteConfiguration)

Route = _reflection.GeneratedProtocolMessageType('Route', (_message.Message,), {
  'DESCRIPTOR' : _ROUTE,
  '__module__' : 'envoy.extensions.filters.network.rocketmq_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.rocketmq_proxy.v4alpha.Route)
  })
_sym_db.RegisterMessage(Route)

RouteMatch = _reflection.GeneratedProtocolMessageType('RouteMatch', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEMATCH,
  '__module__' : 'envoy.extensions.filters.network.rocketmq_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteMatch)
  })
_sym_db.RegisterMessage(RouteMatch)

RouteAction = _reflection.GeneratedProtocolMessageType('RouteAction', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEACTION,
  '__module__' : 'envoy.extensions.filters.network.rocketmq_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.rocketmq_proxy.v4alpha.RouteAction)
  })
_sym_db.RegisterMessage(RouteAction)


DESCRIPTOR._options = None
_ROUTECONFIGURATION._options = None
_ROUTE.fields_by_name['match']._options = None
_ROUTE.fields_by_name['route']._options = None
_ROUTE._options = None
_ROUTEMATCH.fields_by_name['topic']._options = None
_ROUTEMATCH._options = None
_ROUTEACTION.fields_by_name['cluster']._options = None
_ROUTEACTION._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/udp/udp_proxy/v3/udp_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/udp/udp_proxy/v3/udp_proxy.proto',
  package='envoy.extensions.filters.udp.udp_proxy.v3',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.extensions.filters.udp.udp_proxy.v3B\rUdpProxyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9envoy/extensions/filters/udp/udp_proxy/v3/udp_proxy.proto\x12)envoy.extensions.filters.udp.udp_proxy.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x9d\x03\n\x0eUdpProxyConfig\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1a\n\x07\x63luster\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12/\n\x0cidle_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13use_original_src_ip\x18\x04 \x01(\x08\x12\x65\n\rhash_policies\x18\x05 \x03(\x0b\x32\x44.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.HashPolicyB\x08\xfa\x42\x05\x92\x01\x02\x10\x01\x1a\x43\n\nHashPolicy\x12\x1c\n\tsource_ip\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x42\x17\n\x10policy_specifier\x12\x03\xf8\x42\x01:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfigB\x16\n\x0froute_specifier\x12\x03\xf8\x42\x01\x42R\n7io.envoyproxy.envoy.extensions.filters.udp.udp_proxy.v3B\rUdpProxyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_UDPPROXYCONFIG_HASHPOLICY = _descriptor.Descriptor(
  name='HashPolicy',
  full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.HashPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_ip', full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.HashPolicy.source_ip', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='policy_specifier', full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.HashPolicy.policy_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=485,
  serialized_end=552,
)

_UDPPROXYCONFIG = _descriptor.Descriptor(
  name='UdpProxyConfig',
  full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.stat_prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.cluster', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_timeout', full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.idle_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_original_src_ip', full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.use_original_src_ip', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash_policies', full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.hash_policies', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UDPPROXYCONFIG_HASHPOLICY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036:\n8envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='route_specifier', full_name='envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.route_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=228,
  serialized_end=641,
)

_UDPPROXYCONFIG_HASHPOLICY.containing_type = _UDPPROXYCONFIG
_UDPPROXYCONFIG_HASHPOLICY.oneofs_by_name['policy_specifier'].fields.append(
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['source_ip'])
_UDPPROXYCONFIG_HASHPOLICY.fields_by_name['source_ip'].containing_oneof = _UDPPROXYCONFIG_HASHPOLICY.oneofs_by_name['policy_specifier']
_UDPPROXYCONFIG.fields_by_name['idle_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_UDPPROXYCONFIG.fields_by_name['hash_policies'].message_type = _UDPPROXYCONFIG_HASHPOLICY
_UDPPROXYCONFIG.oneofs_by_name['route_specifier'].fields.append(
  _UDPPROXYCONFIG.fields_by_name['cluster'])
_UDPPROXYCONFIG.fields_by_name['cluster'].containing_oneof = _UDPPROXYCONFIG.oneofs_by_name['route_specifier']
DESCRIPTOR.message_types_by_name['UdpProxyConfig'] = _UDPPROXYCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UdpProxyConfig = _reflection.GeneratedProtocolMessageType('UdpProxyConfig', (_message.Message,), {

  'HashPolicy' : _reflection.GeneratedProtocolMessageType('HashPolicy', (_message.Message,), {
    'DESCRIPTOR' : _UDPPROXYCONFIG_HASHPOLICY,
    '__module__' : 'envoy.extensions.filters.udp.udp_proxy.v3.udp_proxy_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.HashPolicy)
    })
  ,
  'DESCRIPTOR' : _UDPPROXYCONFIG,
  '__module__' : 'envoy.extensions.filters.udp.udp_proxy.v3.udp_proxy_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig)
  })
_sym_db.RegisterMessage(UdpProxyConfig)
_sym_db.RegisterMessage(UdpProxyConfig.HashPolicy)


DESCRIPTOR._options = None
_UDPPROXYCONFIG_HASHPOLICY.oneofs_by_name['policy_specifier']._options = None
_UDPPROXYCONFIG_HASHPOLICY.fields_by_name['source_ip']._options = None
_UDPPROXYCONFIG.oneofs_by_name['route_specifier']._options = None
_UDPPROXYCONFIG.fields_by_name['stat_prefix']._options = None
_UDPPROXYCONFIG.fields_by_name['cluster']._options = None
_UDPPROXYCONFIG.fields_by_name['hash_policies']._options = None
_UDPPROXYCONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/proxy_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/proxy_protocol.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\022ProxyProtocolProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)envoy/config/core/v3/proxy_protocol.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1dudpa/annotations/status.proto\"t\n\x13ProxyProtocolConfig\x12\x42\n\x07version\x18\x01 \x01(\x0e\x32\x31.envoy.config.core.v3.ProxyProtocolConfig.Version\"\x19\n\x07Version\x12\x06\n\x02V1\x10\x00\x12\x06\n\x02V2\x10\x01\x42\x42\n\"io.envoyproxy.envoy.config.core.v3B\x12ProxyProtocolProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])



_PROXYPROTOCOLCONFIG_VERSION = _descriptor.EnumDescriptor(
  name='Version',
  full_name='envoy.config.core.v3.ProxyProtocolConfig.Version',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='V1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='V2', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=189,
  serialized_end=214,
)
_sym_db.RegisterEnumDescriptor(_PROXYPROTOCOLCONFIG_VERSION)


_PROXYPROTOCOLCONFIG = _descriptor.Descriptor(
  name='ProxyProtocolConfig',
  full_name='envoy.config.core.v3.ProxyProtocolConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='envoy.config.core.v3.ProxyProtocolConfig.version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROXYPROTOCOLCONFIG_VERSION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=98,
  serialized_end=214,
)

_PROXYPROTOCOLCONFIG.fields_by_name['version'].enum_type = _PROXYPROTOCOLCONFIG_VERSION
_PROXYPROTOCOLCONFIG_VERSION.containing_type = _PROXYPROTOCOLCONFIG
DESCRIPTOR.message_types_by_name['ProxyProtocolConfig'] = _PROXYPROTOCOLCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProxyProtocolConfig = _reflection.GeneratedProtocolMessageType('ProxyProtocolConfig', (_message.Message,), {
  'DESCRIPTOR' : _PROXYPROTOCOLCONFIG,
  '__module__' : 'envoy.config.core.v3.proxy_protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.ProxyProtocolConfig)
  })
_sym_db.RegisterMessage(ProxyProtocolConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/distribution.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicecontrol/v1/distribution.proto',
  package='google.api.servicecontrol.v1',
  syntax='proto3',
  serialized_options=b'\n com.google.api.servicecontrol.v1B\021DistributionProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/google/api/servicecontrol/v1/distribution.proto\x12\x1cgoogle.api.servicecontrol.v1\"\xe8\x04\n\x0c\x44istribution\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\x0c\n\x04mean\x18\x02 \x01(\x01\x12\x0f\n\x07minimum\x18\x03 \x01(\x01\x12\x0f\n\x07maximum\x18\x04 \x01(\x01\x12 \n\x18sum_of_squared_deviation\x18\x05 \x01(\x01\x12\x15\n\rbucket_counts\x18\x06 \x03(\x03\x12R\n\x0elinear_buckets\x18\x07 \x01(\x0b\x32\x38.google.api.servicecontrol.v1.Distribution.LinearBucketsH\x00\x12\\\n\x13\x65xponential_buckets\x18\x08 \x01(\x0b\x32=.google.api.servicecontrol.v1.Distribution.ExponentialBucketsH\x00\x12V\n\x10\x65xplicit_buckets\x18\t \x01(\x0b\x32:.google.api.servicecontrol.v1.Distribution.ExplicitBucketsH\x00\x1aJ\n\rLinearBuckets\x12\x1a\n\x12num_finite_buckets\x18\x01 \x01(\x05\x12\r\n\x05width\x18\x02 \x01(\x01\x12\x0e\n\x06offset\x18\x03 \x01(\x01\x1aV\n\x12\x45xponentialBuckets\x12\x1a\n\x12num_finite_buckets\x18\x01 \x01(\x05\x12\x15\n\rgrowth_factor\x18\x02 \x01(\x01\x12\r\n\x05scale\x18\x03 \x01(\x01\x1a!\n\x0f\x45xplicitBuckets\x12\x0e\n\x06\x62ounds\x18\x01 \x03(\x01\x42\x0f\n\rbucket_optionB\x86\x01\n com.google.api.servicecontrol.v1B\x11\x44istributionProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\x62\x06proto3'
)




_DISTRIBUTION_LINEARBUCKETS = _descriptor.Descriptor(
  name='LinearBuckets',
  full_name='google.api.servicecontrol.v1.Distribution.LinearBuckets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_finite_buckets', full_name='google.api.servicecontrol.v1.Distribution.LinearBuckets.num_finite_buckets', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='google.api.servicecontrol.v1.Distribution.LinearBuckets.width', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='google.api.servicecontrol.v1.Distribution.LinearBuckets.offset', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=558,
)

_DISTRIBUTION_EXPONENTIALBUCKETS = _descriptor.Descriptor(
  name='ExponentialBuckets',
  full_name='google.api.servicecontrol.v1.Distribution.ExponentialBuckets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_finite_buckets', full_name='google.api.servicecontrol.v1.Distribution.ExponentialBuckets.num_finite_buckets', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='growth_factor', full_name='google.api.servicecontrol.v1.Distribution.ExponentialBuckets.growth_factor', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scale', full_name='google.api.servicecontrol.v1.Distribution.ExponentialBuckets.scale', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=646,
)

_DISTRIBUTION_EXPLICITBUCKETS = _descriptor.Descriptor(
  name='ExplicitBuckets',
  full_name='google.api.servicecontrol.v1.Distribution.ExplicitBuckets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bounds', full_name='google.api.servicecontrol.v1.Distribution.ExplicitBuckets.bounds', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=648,
  serialized_end=681,
)

_DISTRIBUTION = _descriptor.Descriptor(
  name='Distribution',
  full_name='google.api.servicecontrol.v1.Distribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='google.api.servicecontrol.v1.Distribution.count', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean', full_name='google.api.servicecontrol.v1.Distribution.mean', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum', full_name='google.api.servicecontrol.v1.Distribution.minimum', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum', full_name='google.api.servicecontrol.v1.Distribution.maximum', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sum_of_squared_deviation', full_name='google.api.servicecontrol.v1.Distribution.sum_of_squared_deviation', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_counts', full_name='google.api.servicecontrol.v1.Distribution.bucket_counts', index=5,
      number=6, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_buckets', full_name='google.api.servicecontrol.v1.Distribution.linear_buckets', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exponential_buckets', full_name='google.api.servicecontrol.v1.Distribution.exponential_buckets', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='explicit_buckets', full_name='google.api.servicecontrol.v1.Distribution.explicit_buckets', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DISTRIBUTION_LINEARBUCKETS, _DISTRIBUTION_EXPONENTIALBUCKETS, _DISTRIBUTION_EXPLICITBUCKETS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='bucket_option', full_name='google.api.servicecontrol.v1.Distribution.bucket_option',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=82,
  serialized_end=698,
)

_DISTRIBUTION_LINEARBUCKETS.containing_type = _DISTRIBUTION
_DISTRIBUTION_EXPONENTIALBUCKETS.containing_type = _DISTRIBUTION
_DISTRIBUTION_EXPLICITBUCKETS.containing_type = _DISTRIBUTION
_DISTRIBUTION.fields_by_name['linear_buckets'].message_type = _DISTRIBUTION_LINEARBUCKETS
_DISTRIBUTION.fields_by_name['exponential_buckets'].message_type = _DISTRIBUTION_EXPONENTIALBUCKETS
_DISTRIBUTION.fields_by_name['explicit_buckets'].message_type = _DISTRIBUTION_EXPLICITBUCKETS
_DISTRIBUTION.oneofs_by_name['bucket_option'].fields.append(
  _DISTRIBUTION.fields_by_name['linear_buckets'])
_DISTRIBUTION.fields_by_name['linear_buckets'].containing_oneof = _DISTRIBUTION.oneofs_by_name['bucket_option']
_DISTRIBUTION.oneofs_by_name['bucket_option'].fields.append(
  _DISTRIBUTION.fields_by_name['exponential_buckets'])
_DISTRIBUTION.fields_by_name['exponential_buckets'].containing_oneof = _DISTRIBUTION.oneofs_by_name['bucket_option']
_DISTRIBUTION.oneofs_by_name['bucket_option'].fields.append(
  _DISTRIBUTION.fields_by_name['explicit_buckets'])
_DISTRIBUTION.fields_by_name['explicit_buckets'].containing_oneof = _DISTRIBUTION.oneofs_by_name['bucket_option']
DESCRIPTOR.message_types_by_name['Distribution'] = _DISTRIBUTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Distribution = _reflection.GeneratedProtocolMessageType('Distribution', (_message.Message,), {

  'LinearBuckets' : _reflection.GeneratedProtocolMessageType('LinearBuckets', (_message.Message,), {
    'DESCRIPTOR' : _DISTRIBUTION_LINEARBUCKETS,
    '__module__' : 'google.api.servicecontrol.v1.distribution_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.Distribution.LinearBuckets)
    })
  ,

  'ExponentialBuckets' : _reflection.GeneratedProtocolMessageType('ExponentialBuckets', (_message.Message,), {
    'DESCRIPTOR' : _DISTRIBUTION_EXPONENTIALBUCKETS,
    '__module__' : 'google.api.servicecontrol.v1.distribution_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.Distribution.ExponentialBuckets)
    })
  ,

  'ExplicitBuckets' : _reflection.GeneratedProtocolMessageType('ExplicitBuckets', (_message.Message,), {
    'DESCRIPTOR' : _DISTRIBUTION_EXPLICITBUCKETS,
    '__module__' : 'google.api.servicecontrol.v1.distribution_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.Distribution.ExplicitBuckets)
    })
  ,
  'DESCRIPTOR' : _DISTRIBUTION,
  '__module__' : 'google.api.servicecontrol.v1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.Distribution)
  })
_sym_db.RegisterMessage(Distribution)
_sym_db.RegisterMessage(Distribution.LinearBuckets)
_sym_db.RegisterMessage(Distribution.ExponentialBuckets)
_sym_db.RegisterMessage(Distribution.ExplicitBuckets)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v4alpha/udp_gso_batch_writer_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/listener/v4alpha/udp_gso_batch_writer_config.proto',
  package='envoy.config.listener.v4alpha',
  syntax='proto3',
  serialized_options=b'\n+io.envoyproxy.envoy.config.listener.v4alphaB\034UdpGsoBatchWriterConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?envoy/config/listener/v4alpha/udp_gso_batch_writer_config.proto\x12\x1d\x65nvoy.config.listener.v4alpha\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"T\n\x18UdpGsoBatchWriterOptions:8\x9a\xc5\x88\x1e\x33\n1envoy.config.listener.v3.UdpGsoBatchWriterOptionsBU\n+io.envoyproxy.envoy.config.listener.v4alphaB\x1cUdpGsoBatchWriterConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_UDPGSOBATCHWRITEROPTIONS = _descriptor.Descriptor(
  name='UdpGsoBatchWriterOptions',
  full_name='envoy.config.listener.v4alpha.UdpGsoBatchWriterOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0363\n1envoy.config.listener.v3.UdpGsoBatchWriterOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=248,
)

DESCRIPTOR.message_types_by_name['UdpGsoBatchWriterOptions'] = _UDPGSOBATCHWRITEROPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UdpGsoBatchWriterOptions = _reflection.GeneratedProtocolMessageType('UdpGsoBatchWriterOptions', (_message.Message,), {
  'DESCRIPTOR' : _UDPGSOBATCHWRITEROPTIONS,
  '__module__' : 'envoy.config.listener.v4alpha.udp_gso_batch_writer_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v4alpha.UdpGsoBatchWriterOptions)
  })
_sym_db.RegisterMessage(UdpGsoBatchWriterOptions)


DESCRIPTOR._options = None
_UDPGSOBATCHWRITEROPTIONS._options = None
# @@protoc_insertion_point(module_scope)
